LabelField class

Inheritance

Constructors

LabelField({Key? key, String hintText = '', required TextEditingController controller, TextAlign textAlign = TextAlign.left, bool isNum = false, required String label, required double wid1, required double wid2, double hei1 = 35, double hei2 = 35, bool isFilled = true, TextStyle textStyle = const TextStyle(), EdgeInsets contentPadding = const EdgeInsets.symmetric(horizontal: 5), Color fillColor = Colors.white, double borderRadius = 5, bool obscureText = false})
const

Properties

borderRadius double
final
contentPadding EdgeInsets
final
controller TextEditingController
final
fillColor Color
final
hashCode int
The hash code for this object.
no setterinherited
hei1 double
final
hei2 double
final
hintText String
final
isFilled bool
final
isNum bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
final
obscureText bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textAlign TextAlign
final
textStyle TextStyle
final
wid1 double
final
wid2 double
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited